birthdayimage = [
  "https://telegra.ph/file/ee6144a3890cc93002eec.jpg",
  "https://telegra.ph/file/145a092d1ec22047e95f3.jpg",
  "https://telegra.ph/file/0d7ea53b67247e326aa10.jpg",
  "https://graph.org/file/7773a18f9dd8b485cf8fa.jpg",
  "https://graph.org/file/c01fe5cdbc8729d7fde12.jpg",
  "https://graph.org/file/d693507baa5dfa8876033.jpg",
  "https://graph.org/file/efb689ca636da639c529b.jpg",
  "https://graph.org/file/7e02c1c0486d8b4407a77.jpg",
  "https://graph.org/file/7e02c1c0486d8b4407a77.jpg",
  "https://graph.org/file/8bc4fe5a6a40fa1fe237f.jpg",
  "https://graph.org/file/d879c5594a8dc75076ebc.jpg",
  "https://graph.org/file/1d87591e63f643514d984.jpg",
  "https://graph.org/file/15b62531477dc8f581926.jpg",
  "https://graph.org/file/11da631e533bd4595de19.jpg",
  "https://graph.org/file/642961ba281179da9311d.jpg",
  "https://graph.org/file/02f4bbb30666c2ca2cd5f.jpg",
  "https://graph.org/file/4061fbaf441d6a8f5c748.jpg",
  "https://graph.org/file/0944b095d8bac72877ef5.jpg",
  "https://graph.org/file/98c2408c8cf91555f8143.jpg",
]


bdmsg = [
  "🍫🎂Happy Birthday. I’m hoping this birthday is the start of a fantastic year filled with success and lots of great times!🎂😍",
  "🍧The sun is shining more brightly today as a way to wish you happy birthday.🎂🍧",
  "🎂🍫🎂🍫🎂🍫🎂🍫🎂🍫🎂🍫🎂🍫🎂\n🌟बहुत-बहुत मुबारक हो यह समा आपको,\n    बहुत ही नायब लग रहा है यह जहां💞💞\n    आपसे दूर हूं स्वीकार कीजिए यह संदेश,\nआप के जन्मदिन पे सजा है यह सारा जहां..🤍",
  "       🌹सुगन्धित हो जीवन आपका.....\nतारों की चमक से सम्मिलित हो जीवन \nआपका\nशुभ दिन ये आये आपके जीवन में हजार बार...🍭\nऔर हम \nआपको जन्मदिन मुबारक कहते रहें हर बार.\n     🎂🍁🎂🍁🎂🍁🎂🍁🎂🍁🎂🍁🎂",
  "     ❄️बुलंद रहे हमेशा आपके सितारे,\nटलती रहें आपकी सारी बलाएं.....\nइसी दुआ के साथ आपको......\n     जन्मदिन की हार्दिक शुभकामनाएँ❄️",
]


