abuse = [
    "MADHARCHOD",
    "TERIII BHEN KII CHUUTTTT",
    "Teri ma ki chut",
    "OYEE RANDIII KEE BACHE😈😈TERIII BHEN KIII CHUUUTTTTTTTTTT",
    "𝙎𝙋𝙀𝙀𝘿 𝙋𝙆𝘿𝘿𝘿",
    "𝙂𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣 𝙇𝙒𝘿𝘼 𝘿𝘼𝙇 𝙇𝙀 𝘼𝙋𝙉𝙄 𝙈𝙀𝙍𝘼𝘼𝘼",
    "𝙂𝙖𝙖𝙣𝙙 𝙢𝙚𝙞𝙣 𝙗𝙖𝙢𝙗𝙪 𝘿𝙀𝘿𝙐𝙉𝙂𝘼𝘼𝘼𝘼𝘼𝘼",
    "𝙂𝘼𝙉𝘿 𝙁𝙏𝙄 𝙆𝙀 𝘽𝘼𝙇𝙆𝙆𝙆",
    "𝙂𝙤𝙩𝙚 𝙠𝙞𝙩𝙣𝙚 𝙗𝙝𝙞 𝙗𝙖𝙙𝙚 𝙝𝙤, 𝙡𝙪𝙣𝙙 𝙠𝙚 𝙣𝙞𝙘𝙝𝙚 𝙝𝙞 𝙧𝙚𝙝𝙩𝙚 𝙝𝙖𝙞",
    "𝙃𝙖𝙯𝙖𝙖𝙧 𝙡𝙪𝙣𝙙 𝙩𝙚𝙧𝙞 𝙜𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣",
    "𝙅𝙝𝙖𝙖𝙣𝙩 𝙠𝙚 𝙥𝙞𝙨𝙨𝙪-",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝙄 𝙆𝘼𝙇𝙄 𝘾𝙃𝙐𝙏",
    "𝙆𝙝𝙤𝙩𝙚𝙮 𝙠𝙞 𝙖𝙪𝙡𝙙𝙖",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙖 𝙖𝙬𝙡𝙖𝙩",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙞 𝙟𝙖𝙩",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙚 𝙩𝙖𝙩𝙩𝙚",
    "𝙏𝙀𝙏𝙄 𝙈𝘼 𝙆𝙄.𝘾𝙃𝙐𝙏 , 𝙩𝙀𝙍𝙄 𝙈𝘼 𝙍𝙉𝘿𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄",
    "𝙇𝙖𝙫𝙙𝙚 𝙠𝙚 𝙗𝙖𝙡",
    "𝙢𝙪𝙝 𝙢𝙚𝙞 𝙡𝙚𝙡𝙚",
    "𝙇𝙪𝙣𝙙 𝙆𝙚 𝙋𝙖𝙨𝙞𝙣𝙚",
    "𝙈𝙀𝙍𝙀 𝙇𝙒𝘿𝙀 𝙆𝙀 𝘽𝘼𝘼𝘼𝘼𝘼𝙇𝙇𝙇",
    "𝙃𝘼𝙃𝘼𝙃𝘼𝘼𝘼𝘼𝘼𝘼",
    "𝘾𝙃𝙐𝘿 𝙂𝙔𝘼𝘼𝘼𝘼𝘼",
    "𝙍𝙖𝙣𝙙𝙞 𝙠𝙝𝙖𝙣𝙀 𝙆𝙄 𝙐𝙇𝘼𝘿𝘿𝘿",
    "𝙎𝙖𝙙𝙞 𝙝𝙪𝙞 𝙜𝙖𝙖𝙣𝙙",
    "𝙏𝙚𝙧𝙞 𝙜𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣 𝙠𝙪𝙩𝙚 𝙠𝙖 𝙡𝙪𝙣𝙙",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙠𝙖 𝙗𝙝𝙤𝙨𝙙𝙖",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙠𝙞 𝙘𝙝𝙪𝙩",
    "𝙏𝙚𝙧𝙚 𝙜𝙖𝙖𝙣𝙙 𝙢𝙚𝙞𝙣 𝙠𝙚𝙚𝙙𝙚 𝙥𝙖𝙙𝙖𝙮",
    "𝙐𝙡𝙡𝙪 𝙠𝙚 𝙥𝙖𝙩𝙝𝙚",
    "𝙎𝙐𝙉𝙉 𝙈𝘼𝘿𝙀𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼 𝘽𝙃𝙊𝙎𝘿𝘼",
    "𝘽𝙀𝙃𝙀𝙉 𝙆 𝙇𝙐𝙉𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼 𝘾𝙃𝙐𝙏 𝙆𝙄 𝘾𝙃𝙏𝙉𝙄𝙄𝙄𝙄",
    "𝙈𝙀𝙍𝘼 𝙇𝘼𝙒𝘿𝘼 𝙇𝙀𝙇𝙀 𝙏𝙐 𝘼𝙂𝘼𝙍 𝘾𝙃𝘼𝙄𝙔𝙀 𝙏𝙊𝙃",
    "𝙂𝘼𝘼𝙉𝘿𝙐",
    "𝘾𝙃𝙐𝙏𝙄𝙔𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙋𝙀 𝙅𝘾𝘽 𝘾𝙃𝘼𝘿𝙃𝘼𝘼 𝘿𝙐𝙉𝙂𝘼",
    "𝙎𝘼𝙈𝙅𝙃𝘼𝘼 𝙇𝘼𝙒𝘿𝙀",
    "𝙔𝘼 𝘿𝙐 𝙏𝙀𝙍𝙀 𝙂𝘼𝘼𝙉𝘿 𝙈𝙀 𝙏𝘼𝙋𝘼𝘼 𝙏𝘼𝙋��",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙈𝙀𝙍𝘼 𝙍𝙊𝙕 𝙇𝙀𝙏𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙂𝙁 𝙆 𝙎𝘼𝘼𝙏𝙃 𝙈𝙈𝙎 𝘽𝘼𝙉𝘼𝘼 𝘾𝙃𝙐𝙆𝘼 𝙃𝙐���不�不",
    "𝙏𝙐 𝘾𝙃𝙐𝙏𝙄𝙔𝘼 𝙏𝙀𝙍𝘼 𝙆𝙃𝘼𝙉𝘿𝘼𝘼𝙉 𝘾𝙃𝙐𝙏𝙄𝙔𝘼",
    "𝘼𝙐𝙍 𝙆𝙄𝙏𝙉𝘼 𝘽𝙊𝙇𝙐 𝘽𝙀𝙔 𝙈𝘼𝙉𝙉 𝘽𝙃𝘼𝙍 𝙂𝘼𝙔𝘼 𝙈𝙀𝙍𝘼�不",
    "𝙏𝙀𝙍𝙄𝙄𝙄𝙄𝙄𝙄 𝙈𝘼𝘼𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏𝙏𝙏 𝙈𝙀 𝘼𝘽𝘾𝘿 𝙇𝙄𝙆𝙃 𝘿𝙐𝙉𝙂𝘼 𝙈𝘼𝘼 𝙆𝙀 𝙇𝙊𝘿𝙀",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙇𝙀𝙆𝘼𝙍 𝙈𝘼𝙄 𝙁𝘼𝙍𝘼𝙍",
    "𝙍𝘼𝙉𝙄𝘿𝙄𝙄𝙄",
    "𝘽𝘼𝘾𝙃𝙀𝙀",
    "𝘾𝙃𝙊𝘿𝙐",
    "𝙍𝘼𝙉𝘿𝙄",
    "𝙍𝘼𝙉𝘿𝙄 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀",
    "𝙏𝙀𝙍𝙄𝙄𝙄𝙄𝙄 𝙈𝘼𝘼𝘼 𝙆𝙊 𝘽𝙃𝙀𝙅𝙅𝙅",
    "𝙏𝙀𝙍𝘼𝘼 𝘽𝘼𝘼𝘼𝘼𝙋 𝙃𝙐",
    "𝙩𝙚𝙧𝙞 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙃𝘼𝘼𝙏 𝘿𝘼𝘼𝙇𝙇𝙆𝙀 𝘽𝙃𝘼𝘼𝙂 𝙅𝘼𝘼𝙉𝙐𝙂𝘼",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙆𝙊 𝙎𝘼𝙍𝘼𝙆 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙂𝘽 𝙍𝙊𝘼𝘿 𝙋𝙀 𝙇𝙀𝙅𝘼𝙆𝙀 𝘽𝙀𝘾𝙃 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀‌ 𝙆𝘼𝘼𝙇𝙄 𝙈𝙄𝙏𝘾𝙃",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙎𝘼𝙎𝙏𝙄 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙆𝘼𝘽𝙐𝙏𝘼𝙍 𝘿𝘼𝘼𝙇 𝙆𝙀 𝙎𝙊𝙐𝙋 𝘽𝘼𝙉𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝘿𝙀𝙏𝙊𝙇 𝘿𝘼𝘼𝙇 𝘿𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙇𝘼𝙋𝙏𝙊𝙋",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝘽𝙄𝙎𝙏𝘼𝙍 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼𝙆𝙀 𝘾𝙃𝙊𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝘼𝙈𝙀𝙍𝙄𝘾𝘼 𝙂𝙃𝙐𝙈𝘼𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙉𝘼𝘼𝙍𝙄𝙔𝘼𝙇 𝙋𝙃𝙊𝙍 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙀 𝙂𝘼𝙉𝘿 𝙈𝙀 𝘿𝙀𝙏𝙊𝙇 𝘿𝘼𝘼𝙇 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙆𝙊 𝙃𝙊𝙍𝙇𝙄𝘾𝙆𝙎 𝙋𝙄𝙇𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙎𝘼𝙍𝘼𝙆 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼𝘼 𝘿𝙐𝙉𝙂𝘼𝘼𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼",
    "𝙈𝙀𝙍𝘼𝘼𝘼 𝙇𝙐𝙉𝘿 𝙋𝘼𝙆𝘼𝘿 𝙇𝙀 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝘾𝙃𝙐𝙋 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝘼𝙆𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼𝘼",
    "𝙏𝙀𝙍𝙄𝙄𝙄 𝙈𝘼𝘼 𝘾𝙃𝙐𝙁 𝙂𝙀𝙔𝙄𝙄 𝙆𝙔𝘼𝘼𝘼 𝙇𝘼𝙒𝘿𝙀𝙀𝙀",
    "𝙏𝙀𝙍𝙄𝙄𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼 𝘽𝙅𝙎𝙊𝘿𝘼𝘼𝘼",
    "𝙈𝘼𝘿𝘼𝙍𝙓𝙃𝙊𝘿𝘿𝘿",
    ]
